@@ -15,6 +15,7 @@ import os
 import shutil
 import sys
 from collections.abc import Callable
+from typing import Union
 
 import __main__
 
@@ -47,8 +48,7 @@ class Plugins:
 
         self._is_limited_host = False
 
-        self._used_plugins: dict[str,
-                                 tuple[str, Callable[[], list[str]], str]] = {}
+        self._used_plugins: dict[str, tuple[str, Callable[[], list[str]], str]] = {}
         # self._used_plugins: dict[
         #     str, tuple[str, Callable[[], tuple[str, str, str]], str]
         # ] = {}  # plugins that will be used
@@ -72,14 +72,19 @@ class Plugins:
             self.clear()
 
     def found(self, short_name=True):
-        """Returns a list of plugin names being used."""
+        """Returns a list of plugin names being used.
+        If short_name is False will return the full name including
+        source, this is needed when cloning the repo, but less desired
+        when just checking if a given plugin is used in most cases.
+        Since if a different fork of it is being used, the name would
+        not match."""
         result = []
-        for full_name in self._used_plugins.keys():
+        for full_name in self._used_plugins:
             name = full_name
             if short_name:
                 # Try to return only actual plugin name, without provider
-                if full_name.find('/') > -1:
-                    name = full_name.split('/')[1]
+                if full_name.find("/") > -1:
+                    name = full_name.split("/")[1]
             result.append(name)
         return result
 
@@ -95,11 +100,19 @@ class Plugins:
     # ================================================================
 
     def set_limited_host(self, is_limited: bool) -> bool:
+        """For this module, this indicates that the host is considered
+        slowish, so extended status updates should be provided during
+        plugin init, to help indicating when all the plugins are setup.
+        Om normalish system, this is close to instantaneous, so step by
+        step progress is not really meaningful.
+        """
         self._is_limited_host = is_limited
         return self._is_limited_host
 
-    def scan(self, plugin_methods: list[Callable[[], list[str]]]) -> None:
-        duplicate_check: list[str] = []
+    def scan(self, plugin_methods) -> None:
+        """Investigate all defined plugin methods, and determine if a
+        given plugin can be used depending on running tmux"""
+        duplicate_check = []
         for plugin_mthd in plugin_methods:
             plugin_name, vers_min, code = plugin_mthd()
             if plugin_name in duplicate_check:
@@ -107,18 +120,20 @@ class Plugins:
                 sys.exit(1)
             else:
                 duplicate_check.append(plugin_name)
-
+            #  Since plugi method might define vers_min as a float
+            #  we need to convert it to a string both for used and ignored plugins
             if self._vers.is_ok(vers_min):
                 self._used_plugins[plugin_name] = (
-                    vers_min,  # self.PLUGIN_VERS_MIN
+                    str(vers_min),  # self.PLUGIN_VERS_MIN
                     plugin_mthd,  # self.PLUGIN_MTHD
                     code,  # self.PLUGIN_STATIC_CODE
                 )
             else:
-                self._skipped_plugins.append((vers_min, plugin_name))
+                self._skipped_plugins.append((str(vers_min), plugin_name))
         self._skipped_plugins.sort()
 
     def display_info(self):
+        """List selected and ignored plugins, depending on param"""
         print(f"\n\t=====  tmux {self._vers.get()} - Plugins defined  =====")
         print(f" for: {__main__.__file__}")
 
@@ -134,29 +149,68 @@ class Plugins:
             print(f'{"Plugin":<{max_l_name}}|  Min version\n')
 
         #
+        #  Create list of items in plugins dir
+        #
+        # plugin_items = next(os.walk(self.get_deploy_dir()))[1]
+        plugin_items = []
+        plugin_dir = self.get_deploy_dir()
+        if os.path.exists(plugin_dir):
+            for f in os.scandir(plugin_dir):
+                if f.is_dir():
+                    plugin_items.append((f.path.split("/")[-1]))
+
+        if "tpm" in plugin_items:
+            plugin_items.remove("tpm")
+        #
         #  When exec'ing the plugin code below, write output to stdout,
         #  not to config file. Since program will exit after displaying
         #  plugin details, no need to reset this variable.
         #
         verbose = self._plugins_display == 3
 
+        missing_plugins = []
         for name, info in self._used_plugins.items():
             if verbose:
-                print("".ljust(len(name), "-"))
-                print(f"> {name:<{max_l_name - 2}} - {info[PLUGIN_VERS_MIN]}")
+                sans_prefix = name.split("/")[1]
+                if sans_prefix in plugin_items:
+                    plugin_items.remove(sans_prefix)
+                    suffix = ""
+                else:
+                    suffix = " *** Not installed ***"
+                print("".ljust(len(name) + 2, "-"))
+                print(f"> {name:<{max_l_name - 2}} - {info[PLUGIN_VERS_MIN]} {suffix}")
                 info[PLUGIN_MTHD]()
                 #
                 #  Skip indention, for easier read
                 #
                 for line in info[PLUGIN_STATIC_CODE].split("\n"):
-                    if line := line.strip():
-                        print(f"{line}")
-                print()
+                    # if line == line.strip():
+                    print(f"{line.strip()}")
+                # print()
             else:
-                print(f"{name:<{max_l_name}} - {info[PLUGIN_VERS_MIN]}")
+                sans_prefix = name.split("/")[1]
+                if sans_prefix in plugin_items:
+                    plugin_items.remove(sans_prefix)
+                    suffix = ""
+                else:
+                    suffix = " *** Not installed ***"
+                print(f"{name:<{max_l_name}} - {info[PLUGIN_VERS_MIN]} {suffix}")
+
+        for _, name in self._skipped_plugins:
+            if name.find("/") > -1:
+                sans_prefix = name.split("/")[1]
+            else:
+                sans_prefix = name
+            if sans_prefix in plugin_items:
+                plugin_items.remove(sans_prefix)
+
+        if plugin_items:
+            print("\n-----   Unused plugins found   -----")
+            for s in plugin_items:
+                print("\t", s)
 
         if not self._skipped_plugins or self._plugins_display != 2:
-            sys.exit(1)
+            sys.exit(0)
 
         if self._skipped_plugins:
             print()
@@ -165,15 +219,15 @@ class Plugins:
         self._skipped_plugins.sort()
         for vers, name in self._skipped_plugins:
             max_l_v = max(max_l_v, len(vers))
-        print("\t-----   Plugins ignored   -----")
+        print("-----   Plugins ignored   -----")
         print(f'{"Min":<{max_l_v}}|{" Plugin name":<{max_l_name}}')
         print(f'{"vers":<{max_l_v}}|\n')
         for vers, name in self._skipped_plugins:
             print(f"{vers:>{max_l_v}}  {name:<{max_l_name}}")
 
-        sys.exit(1)
+        sys.exit(0)
 
-    def parse(self) -> list[str]:
+    def parse(self):
         """This package will use any plugin defining methods it can find.
         They will be sorted alphabetically by method name, normally the order
         of plugins do not matter, but if you do want to force the sorting,
@@ -195,7 +249,7 @@ class Plugins:
         if not (self._used_plugins):
             return []
 
-        output: list = []
+        output: list[Union[str, list[str]]] = []
 
         #
         #  First ensure that plugin code that needs to process the
@@ -220,8 +274,7 @@ class Plugins:
             #  plugin and install if missing
             #
             output.append(self.mkscript_manual_deploy())
-            output.append(self._es.run_it(
-                self._fnc_activate_manually, in_bg=True))
+            output.append(self._es.run_it(self._fnc_activate_manually, in_bg=True))
         elif self._plugin_handler:
             #
             #  For any other _plugin_handler setting, assume it is tpm
@@ -232,7 +285,7 @@ class Plugins:
         output.append("")  # spacer between sections
         return output
 
-    def get_env(self) -> tuple[str, str]:
+    def get_env(self):
         location = os.path.dirname(os.path.expanduser(self._conf_file))
         if location == os.path.expanduser("~"):
             #
@@ -273,7 +326,11 @@ class Plugins:
             )
         return plugins_dir, tpm_env
 
-    def mkscript_manual_deploy(self) -> list[str]:
+    def mkscript_manual_deploy(self):
+        """This script is run as tmux starts, all non-present
+        plugins are installed, and an attempt is done to initialize
+        each plugin.
+        """
         output = []
         output.append(
             """
@@ -286,7 +343,7 @@ class Plugins:
         )
         plugins_dir, _ = self.get_env()
         plugins = ""
-        for p in self.found():
+        for p in self.found(short_name=False):
             plugins += " " + p
 
         activate_manually_sh = [
@@ -306,13 +363,10 @@ class Plugins:
             git clone "https://github.com/$plugin" "{plugins_dir}/$name"
         fi
         init_script="$(find "{plugins_dir}/$name" -maxdepth 1 | grep tmux$ | head -n 1)"
-        if [[ -z "$init_script" ]]; then
-            echo "ERROR: Could not find $name init script"
-            exit 1
+        if [[ -n "$init_script" ]]; then
+            $TMUX_BIN display "running: $init_script"
+            $init_script || echo "ERROR in $init_script"
         fi
-        $TMUX_BIN display "running: $init_script"
-        #  run init script
-        $init_script || echo "ERROR in $init_script"
     done
 }}""",
         ]
@@ -321,7 +375,11 @@ class Plugins:
         )
         return output
 
-    def mkscript_tpm_deploy(self) -> list[str]:
+    def mkscript_tpm_deploy(self):
+        """If tpm is present, it is started.
+        If not, it is installed and requested to install all
+        defined plugins.
+        """
         output = []
         output.append(
             """
@@ -384,7 +442,7 @@ class Plugins:
     fi
 
     #
-    #  this only triggers plugins install if tpm needed to be instaled.
+    #  this only triggers plugins install if tpm needed to be installed.
     #  Otherwise installing missing plugins is delegated to tpm.
     #  Default trigger is: <prefix> I
     #
@@ -402,10 +460,9 @@ class Plugins:
         return output
 
     def clear(self):
-        #
-        #  to minimize some bug causing massive file deletion,
-        #  file path is double checked.
-        #
+        """To minimize risk of some bug causing massive file deletion,
+        file path is double checked.
+        """
         plugins_dir = self.get_deploy_dir()
 
         b_suspicious = False
