@@ -103,7 +103,7 @@ class TmuxConfig:
         # then terminate
     ):
         if parse_cmd_line:
-            args = parse_cmdline()
+            args = parse_cmdline(sys.argv[1:])
             conf_file = args.conf_file
             tmux_bin = args.tmux_bin
             tmux_version = args.forced_version
@@ -473,7 +473,7 @@ class TmuxConfig:
                         )
                     f.write(f"{line}{eol}")
 
-    def filter_note(self, line: str) -> list[str]:
+    def filter_note(self, line: str):
         """Returns list of lines, if notes are not supported
         first an empty spacer line, then the note as a comment,
         and finally the actual command without the note
@@ -491,7 +491,11 @@ class TmuxConfig:
         parts = line.split("-N")
         pre = parts[0].strip()
         post = parts[1].strip()
-        if (p0 := post[0]) in {'"', "'"}:
+        if not post:
+            # Propably an -N at end of line, so not related to a note
+            return [line]
+        p0 = post[0]
+        if p0 in {'"', "'"}:
             end_note = post[1:].find(p0)
             x = end_note + 1
             note = post[1:x]
@@ -599,7 +603,8 @@ class TmuxConfig:
         the second part of version is int"""
         if not cmd:
             raise SyntaxError("cmd empty")
-        if not (c := shutil.which(cmd)):
+        c = shutil.which(cmd)
+        if not c:
             raise SyntaxError(f"tmux cmd not found: {cmd}")
         cmd = c
         output = run_shell(f"{cmd} -V")
